@@ -173,9 +173,16 @@ mod cli {
             "TEST_QUIRKS.txt",
             MockResponseStats {
                 total: 3,
-                successful: 3,
+                successful: 2,
+                excludes: 1,
                 ..MockResponseStats::default()
-            }
+            },
+            // Currently getting a 429 with Googlebot.
+            // See https://github.com/lycheeverse/lychee/issues/448
+            // See https://twitter.com/matthiasendler/status/1479224185125748737
+            // TODO: Remove this exclusion in the future
+            "--exclude",
+            "twitter"
         )
     }
 
@@ -316,9 +323,9 @@ mod cli {
             .failure()
             .code(1)
             .stderr(contains(format!(
-                "Error: Failed to read file: `{}`, reason: No such file or directory (os error 2)",
-                filename
-            )));
+            "Error: Failed to read from path: `{}`, reason: No such file or directory (os error 2)",
+            filename
+        )));
     }
 
     #[test]
@@ -487,6 +494,39 @@ mod cli {
         Ok(())
     }
 
+    #[test]
+    fn test_lycheeignore_file() -> Result<()> {
+        let mut cmd = main_command();
+        let test_path = fixtures_path().join("ignore");
+
+        cmd.current_dir(test_path)
+            .arg("TEST.md")
+            .assert()
+            .success()
+            .stdout(contains("9 Total"))
+            .stdout(contains("7 Excluded"));
+
+        Ok(())
+    }
+
+    #[test]
+    fn test_lycheeignore_and_exclude_file() -> Result<()> {
+        let mut cmd = main_command();
+        let test_path = fixtures_path().join("ignore");
+        let excludes_path = test_path.join("normal-exclude-file");
+
+        cmd.current_dir(test_path)
+            .arg("TEST.md")
+            .arg("--exclude-file")
+            .arg(excludes_path)
+            .assert()
+            .success()
+            .stdout(contains("9 Total"))
+            .stdout(contains("8 Excluded"));
+
+        Ok(())
+    }
+
     #[test]
     fn test_require_https() -> Result<()> {
         let mut cmd = main_command();
